package com.chelvc.cloud.maintain.controller;

import com.chelvc.cloud.maintain.copier.CommentCopier;
import com.chelvc.cloud.maintain.vo.CommentVO;
import com.chelvc.cloud.vehicle.api.param.AddGoodsCommentParam;
import com.chelvc.cloud.vehicle.api.param.CommentQueryParam;
import com.chelvc.cloud.vehicle.api.service.CommentService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.base.context.SessionContextHolder;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * 商品评价接口
 *
 * @author Woody
 * @date 2023/8/7
 */
@Validated
@RestController
@ResponseWrapping
public class CommentController {
    @DubboReference
    private CommentService commentService;

    /**
     * 获取商品评价列表
     *
     * @param goodsId 商品ID
     * @param parentId   父级评论id
     * @param merchantId   商户id
     * @param param   查询参数
     * @return 商品评价列表
     */
    @GetMapping("/goods/{goodsId}/comments")
    public List<CommentVO> listGoodsComments(
            @PathVariable("goodsId") Long goodsId,
            @PathVariable("parentId") Long parentId,
            @PathVariable("merchantId") Long merchantId,
            @Valid CommentQueryParam param) {
        return CommentCopier.INSTANCE.copying(this.commentService.listGoodsComments(goodsId, parentId, merchantId, param));
    }

    /**
     * 新增商品评价
     *
     * @param param   新增参数
     */
    @PostMapping("/goods/comments/add")
    public void addGoodsComments(@Validated @RequestBody AddGoodsCommentParam param) {
        this.commentService.addGoodsComments(param, SessionContextHolder.getId());
    }
}
