package com.chelvc.cloud.maintain.controller;
import com.chelvc.cloud.vehicle.api.dto.FeedBackDTO;
import com.chelvc.cloud.vehicle.api.param.FeedBackModifyParam;
import com.chelvc.cloud.vehicle.api.service.FeedbackService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 意见反馈接口
 *
 * @author liude
 * @date 2023/1/16
 */
@Validated
@RestController
@ResponseWrapping
public class FeedbackController {
    @DubboReference
    private FeedbackService feedbackService;

    /**
     * 新增意见反馈
     *
     * @param param 新增参数
     * @return 意见反馈主键
     */
    @PostMapping("/feedback")
    public Long addFeedback(@RequestBody @Valid FeedBackModifyParam param) {
        return this.feedbackService.addFeedback(param);
    }

    /**
     * 修改意见反馈
     *
     * @param id    意见反馈主键
     * @param param 修改参数
     */
    @PutMapping("/feedback/{id}")
    public void updateFeedback(@PathVariable("id") @Min(value = 1, message = "商家主键不能小于1") Long id,
                                   @RequestBody @Valid FeedBackModifyParam param) {
        this.feedbackService.updateFeedback(id, param);
    }

    /**
     * 查询意见反馈
     */
    @GetMapping("/feedback/query")
    public List<FeedBackDTO> queryById(@Valid @NotEmpty String channel) {
        return this.feedbackService.getFeedback(channel);
    }



}
