package com.chelvc.cloud.maintain.controller;

import javax.validation.Valid;

import com.chelvc.cloud.maintain.copier.UserCopier;
import com.chelvc.cloud.maintain.vo.PersonalVO;
import com.chelvc.cloud.uc.api.param.PersonalModifyParam;
import com.chelvc.cloud.uc.api.service.UserService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 用户接口
 *
 * @author Woody
 * @date 2023/4/30
 */
@Validated
@RestController
@ResponseWrapping
public class UserController {
    @DubboReference
    private UserService userService;

    /**
     * 获取用户个人信息
     *
     * @return 用户个人信息
     */
    @GetMapping("/user/mine")
    public PersonalVO getPersonal() {
        return UserCopier.INSTANCE.copying(this.userService.getPersonal());
    }

    /**
     * 修改用户个人信息
     *
     * @param param 修改参数
     */
    @PutMapping("/user/mine")
    public void updatePersonal(@RequestBody @Valid PersonalModifyParam param) {
        this.userService.updatePersonal(param);
    }
}
